@@ -379,8 +379,7 @@ plymouth_quit_with_transition (GdmSimpleSlave *slave)
         GError  *error;
 
         error = NULL;
-        res = g_spawn_command_line_sync ("/bin/plymouth quit --retain-splash",
-                                         NULL, NULL, NULL, &error);
+        res = g_spawn_command_line_async ("/bin/plymouth quit --retain-splash", &error);
         if (! res) {
                 g_warning ("Could not quit plymouth: %s", error->message);
                 g_error_free (error);
@@ -395,8 +394,7 @@ plymouth_quit_without_transition (GdmSimpleSlave *slave)
         GError  *error;
 
         error = NULL;
-        res = g_spawn_command_line_sync ("/bin/plymouth quit",
-                                         NULL, NULL, NULL, &error);
+        res = g_spawn_command_line_async ("/bin/plymouth quit", &error);
         if (! res) {
                 g_warning ("Could not quit plymouth: %s", error->message);
                 g_error_free (error);
